[dpdk-dev] [PATCH] bus/dpaa: fix Rx discard mask register

Hemant Agrawal hemant.agrawal at nxp.com
Fri Feb 22 11:09:44 CET 2019


From: Shreyansh Jain <shreyansh.jain at nxp.com>

Current value of 'fmbm_rfsdm' register (0x010CE3F0) doesn't include
the bit to drop colored (red) packets. New value (0x010EE3F0) fixes
this.
Check with 'fmbm_rffc' register of fm_port_bmi_regs.

Fixes: 6d6b4f49a155 ("bus/dpaa: add FMAN hardware operations")

Signed-off-by: Shreyansh Jain <shreyansh.jain at nxp.com>
DPDK-1574
---
 drivers/bus/dpaa/base/fman/fman_hw.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/bus/dpaa/base/fman/fman_hw.c b/drivers/bus/dpaa/base/fman/fman_hw.c
index 4ebbc3d34..9ab8e835d 100644
--- a/drivers/bus/dpaa/base/fman/fman_hw.c
+++ b/drivers/bus/dpaa/base/fman/fman_hw.c
@@ -603,9 +603,9 @@ fman_if_discard_rx_errors(struct fman_if *fm_if)
 	out_be32(fmbm_rfsem, 0);
 
 	/* Configure the discard mask to discard the error packets which have
 	 * DMA errors, Frame size error, Header error etc. The mask 0x010CE3F0
 	 * is to configured discard all the errors which come in the FD[STATUS]
 	 */
 	fmbm_rfsdm = &((struct rx_bmi_regs *)__if->bmi_map)->fmbm_rfsdm;
-	out_be32(fmbm_rfsdm, 0x010CE3F0);
+	out_be32(fmbm_rfsdm, 0x010EE3F0);
 }
@@ -603,9 +603,9 @@ fman_if_discard_rx_errors(struct fman_if *fm_if)
 
 	/* Configure the discard mask to discard the error packets which have
-	 * DMA errors, Frame size error, Header error etc. The mask 0x010CE3F0
+	 * DMA errors, Frame size error, Header error etc. The mask 0x010EE3F0
 	 * is to configured discard all the errors which come in the FD[STATUS]
 	 */
-- 
2.17.1



More information about the dev mailing list